@@ -76,6 +76,7 @@ struct _VCalViewer
 	GtkWidget *who;
 	GtkWidget *start;
 	GtkWidget *end;
+	GtkWidget *location;
 	GtkWidget *summary;
 	GtkWidget *description;
 	gchar	  *url;
@@ -93,11 +94,6 @@ static GtkActionEntry vcalendar_main_menu[] = {{
 	NULL, N_("Create meeting from message..."), NULL, NULL, G_CALLBACK(create_meeting_from_message_cb_ui)
 }};
 
-static GtkActionEntry vcalendar_context_menu[] = {{
-	"SummaryViewPopup/CreateMeeting",
-	NULL, N_("Create meeting from message..."), NULL, NULL, G_CALLBACK(create_meeting_from_message_cb_ui)
-}};
-
 static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data)
 {
 	MainWindow *mainwin = mainwindow_get_mainwindow();
@@ -187,10 +183,10 @@ static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data)
 			} else {
 				g_snprintf(uid, sizeof(uid), "%s", "");
 			}
-			generate_msgid(uid, 255);
+			generate_msgid(uid, 255, account->address);
 			
 			event = vcal_manager_new_event(uid,
-					org, NULL, summary, description, 
+					org, NULL, NULL/*location*/, summary, description, 
 					dtstart, dtend, recur, tzid, url, method, sequence, 
 					ICAL_VTODO_COMPONENT);
 			
@@ -265,7 +261,7 @@ static void vcal_viewer_clear_viewer(MimeViewer *_mimeviewer)
 	vcalviewer->file = NULL;
 	if (vcalviewer->tmpfile) {
 		debug_print("unlinking %s\n", vcalviewer->tmpfile);
-		unlink(vcalviewer->tmpfile);
+		g_unlink(vcalviewer->tmpfile);
 		g_free(vcalviewer->tmpfile);
 		vcalviewer->tmpfile = NULL;
 	}
@@ -299,6 +295,7 @@ static VCalEvent *vcalviewer_get_component(const gchar *file, const gchar *chars
 	if (ferror(fp)) {
 		FILE_OP_ERROR("file stream", "fread");
 		g_byte_array_free(array, TRUE);
+		fclose(fp);
 		return NULL;
 	}
 
@@ -329,6 +326,7 @@ static void vcalviewer_reset(VCalViewer *vcalviewer)
 {
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->type), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
+	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->description), "-");
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->start), "-");
@@ -523,6 +521,13 @@ void vcalviewer_display_event (VCalViewer *vcalviewer, VCalEvent *event)
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
 	}
 
+/* location */
+	if (event->location && *(event->location)) {
+		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), event->location);
+	} else {
+		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location), "-");
+	}
+
 /* summary */
 	if (event->summary && *(event->summary)) {
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), event->summary);
@@ -772,6 +777,9 @@ static void vcalviewer_get_reply_values(VCalViewer *vcalviewer, MimeInfo *mimein
 		GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->who), "-");
 	}
 	
+	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->location),
+		vcalviewer->event->location?vcalviewer->event->location:"-");
+
 	GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->summary), 
 		vcalviewer->event->summary?vcalviewer->event->summary:"-");
 
@@ -866,15 +874,16 @@ static void vcal_viewer_show_mimepart(MimeViewer *_mimeviewer, const gchar *file
 	GTK_EVENTS_FLUSH();
 	gtk_widget_set_size_request(vcalviewer->description, 
 		vcalviewer->scrolledwin->allocation.width - 200, -1);
+	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->location), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->summary), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->description), TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(vcalviewer->attendees), FALSE);
 	
-	if (prefs_common.textfont) {
+	if (prefs_common_get_prefs()->textfont) {
 		PangoFontDescription *font_desc;
 
 		font_desc = pango_font_description_from_string
-						(prefs_common.textfont);
+						(prefs_common_get_prefs()->textfont);
 		if (font_desc) {
 			gtk_widget_modify_font(
 				vcalviewer->description, font_desc);
@@ -1014,7 +1023,7 @@ void vcalendar_cancel_meeting(FolderItem *item, const gchar *uid)
 	vcal_manager_save_event(event, TRUE);
 	
 	file = vcal_manager_get_event_file(event->uid);
-	unlink(file);
+	g_unlink(file);
 	vcal_manager_free_event(event);
 	g_free(file);
 	if (folder)
@@ -1042,7 +1051,7 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 	gint index = gtk_combo_box_get_active(GTK_COMBO_BOX(vcalviewer->answer));
 	enum icalparameter_partstat reply[3] = {ICAL_PARTSTAT_ACCEPTED, ICAL_PARTSTAT_TENTATIVE, ICAL_PARTSTAT_DECLINED};
 	PrefsAccount *account = NULL;
-	
+	VCalEvent *saved_event = NULL, *event = NULL;
 	debug_print("index chosen %d\n", index);
 	
 	if (index < 0 || index > 2) {
@@ -1055,7 +1064,18 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 		g_warning("can't get event\n");
 		return TRUE;
 	}
-	account = vcal_manager_get_account_from_event(vcalviewer->event);
+
+/* see if we have it registered and more recent */
+	event = vcalviewer->event;
+	saved_event = vcal_manager_load_event(vcalviewer->event->uid);
+	if (saved_event && saved_event->sequence >= vcalviewer->event->sequence) {
+		saved_event->method = vcalviewer->event->method;
+		event = saved_event;
+	} else if (saved_event) {
+		vcal_manager_free_event(saved_event);
+		saved_event = NULL;
+	}
+	account = vcal_manager_get_account_from_event(event);
 	
 	if (!account) {
 		AlertValue val = alertpanel_full(_("No account found"), 
@@ -1065,27 +1085,31 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 				   	NULL, ALERT_QUESTION, G_ALERTDEFAULT);
 		if (val == G_ALERTALTERNATE) {		
 			account = account_get_default();
-			vcal_manager_update_answer(vcalviewer->event, account->address, 
+			vcal_manager_update_answer(event, account->address, 
 					account->name,
 					ICAL_PARTSTAT_NEEDSACTION, 
 					ICAL_CUTYPE_INDIVIDUAL);
-		} else
+		} else {
+			if (saved_event)
+				vcal_manager_free_event(saved_event);
 			return TRUE;
+		}
 	}
 	
-	vcal_manager_update_answer(vcalviewer->event, account->address, account->name, reply[index], 0);
+	vcal_manager_update_answer(event, account->address, account->name, reply[index], 0);
 	
-	if (vcalviewer->event->organizer && *(vcalviewer->event->organizer) && 
-	    !vcal_manager_reply(account, vcalviewer->event)) {
+	if (event->organizer && *(event->organizer) && 
+	    !vcal_manager_reply(account, event)) {
 		g_warning("couldn't send reply\n");
 	} else {
 		debug_print("no organizer, not sending answer\n");
 	}
 	
-	vcal_manager_save_event(vcalviewer->event, TRUE);
+	vcal_manager_save_event(event, TRUE);
 
-	vcalviewer_display_event(vcalviewer, vcalviewer->event);
-	
+	vcalviewer_display_event(vcalviewer, event);
+	if (saved_event)
+		vcal_manager_free_event(saved_event);
         return TRUE;
 };
 
@@ -1179,6 +1203,7 @@ MimeViewer *vcal_viewer_create(void)
 	vcalviewer->who = gtk_label_new("who");
 	vcalviewer->start = gtk_label_new("start");
 	vcalviewer->end = gtk_label_new("end");
+	vcalviewer->location = gtk_label_new("location");
 	vcalviewer->summary = gtk_label_new("summary");
 	vcalviewer->description = gtk_label_new("description");
 	vcalviewer->attendees = gtk_label_new("attendees");
@@ -1214,6 +1239,7 @@ MimeViewer *vcal_viewer_create(void)
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->who), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->start), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->end), TRUE);
+	gtk_label_set_selectable(GTK_LABEL(vcalviewer->location), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->summary), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->description), TRUE);
 	gtk_label_set_selectable(GTK_LABEL(vcalviewer->attendees), TRUE);
@@ -1232,6 +1258,7 @@ MimeViewer *vcal_viewer_create(void)
 
 	TABLE_ADD_LINE(_("Event:"), vcalviewer->type);
 	TABLE_ADD_LINE(_("Organizer:"), vcalviewer->who);
+	TABLE_ADD_LINE(_("Location:"), vcalviewer->location);
 	TABLE_ADD_LINE(_("Summary:"), vcalviewer->summary);
 	TABLE_ADD_LINE(_("Starting:"), vcalviewer->start);
 	TABLE_ADD_LINE(_("Ending:"), vcalviewer->end);
@@ -1265,11 +1292,11 @@ MimeViewerFactory vcal_viewer_factory =
 static gint alert_timeout_tag = 0;
 static gint scan_timeout_tag = 0;
 
-static gint vcal_webcal_check(gpointer data)
+static gboolean vcal_webcal_check(gpointer data)
 {
 	Folder *root = folder_find_from_name ("vCalendar", vcal_folder_get_class());
 
-	if (prefs_common.work_offline)
+	if (prefs_common_get_prefs()->work_offline)
 		return TRUE;
 	
 	manual_update = FALSE;
@@ -1284,7 +1311,6 @@ static guint main_menu_id = 0;
 void vcalendar_init(void)
 {
 	MainWindow *mainwin = mainwindow_get_mainwindow();
-	SummaryView *summaryview = mainwin->summaryview;
 	Folder *folder = NULL;
 	gchar *directory = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
 				"vcalendar", NULL);
@@ -1308,6 +1334,10 @@ void vcalendar_init(void)
 		END_TIMING();
 	}
 	if (folder) {
+		if (!folder->inbox) {
+			folder->klass->create_tree(folder);
+			folder_scan_tree(folder, TRUE);
+		}
 		if (folder->klass->scan_required(folder, folder->inbox)) {
 			START_TIMING("scanning folder");
 			folder_item_scan(folder->inbox);
@@ -1318,13 +1348,13 @@ void vcalendar_init(void)
 	vcal_folder_gtk_init();
 
 	alert_timeout_tag = g_timeout_add(60*1000, 
-				(GtkFunction)vcal_meeting_alert_check, 
+				(GSourceFunc)vcal_meeting_alert_check, 
 				(gpointer)NULL);
 	scan_timeout_tag = g_timeout_add(3600*1000, 
-				(GtkFunction)vcal_webcal_check, 
+				(GSourceFunc)vcal_webcal_check, 
 				(gpointer)NULL);
-	if (prefs_common.enable_color) {
-		gtkut_convert_int_to_gdk_color(prefs_common.uri_col,
+	if (prefs_common_get_prefs()->enable_color) {
+		gtkut_convert_int_to_gdk_color(prefs_common_get_prefs()->uri_col,
 				       &uri_color);
 	}
 
@@ -1333,10 +1363,8 @@ void vcalendar_init(void)
 	MENUITEM_ADDUI_ID_MANAGER(mainwin->ui_manager, "/Menu/Message", "CreateMeeting", 
 			  "Message/CreateMeeting", GTK_UI_MANAGER_MENUITEM,
 			  main_menu_id)
-	gtk_action_group_add_actions(summaryview->action_group, vcalendar_context_menu,
-			1, (gpointer)summaryview);
-	MENUITEM_ADDUI_ID("/Menus/SummaryViewPopup", "CreateMeeting", 
-			  "SummaryViewPopup/CreateMeeting", GTK_UI_MANAGER_MENUITEM,
+	MENUITEM_ADDUI_ID_MANAGER(mainwin->ui_manager, "/Menus/SummaryViewPopup", "CreateMeeting", 
+			  "Message/CreateMeeting", GTK_UI_MANAGER_MENUITEM,
 			  context_menu_id)
 	END_TIMING();
 }
@@ -1350,8 +1378,11 @@ void vcalendar_done(void)
 
 	icalmemory_free_ring();
 
+	vcal_folder_free_data();
+
 	if (mainwin == NULL)
 		return;
+
 	summaryview = mainwin->summaryview;
 	folderview = mainwin->folderview;
 	fitem = folderview->summaryview->folder_item;
@@ -1375,6 +1406,6 @@ void vcalendar_done(void)
 
 	MENUITEM_REMUI_MANAGER(mainwin->ui_manager,mainwin->action_group, "Message/CreateMeeting", main_menu_id);
 	main_menu_id = 0;
-	MENUITEM_REMUI(summaryview->action_group, "SummaryViewPopup/CreateMeeting", context_menu_id);
+	MENUITEM_REMUI_MANAGER(mainwin->ui_manager,mainwin->action_group, "Message/CreateMeeting", context_menu_id);
 	context_menu_id = 0;
 }
